==> megaLib-0.9.4.1.tar.gz: megaLib-0.9.4.1/README.md <==
# megaLib
[![image](https://img.shields.io/badge/License-GPLv3-lightgrey.svg)](https://github.com/jvdspeare/megaLib/blob/master/LICENSE)
[![image](https://img.shields.io/badge/Python-3.x-blue.svg)](https://www.python.org/)
[![image](https://img.shields.io/badge/API-Megaport-red.svg)](https://api.megaport.com/)
[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/jvdspeare)

megaLib is a Python wrapper for the [Megaport RESTful API](https://dev.megaport.com/).

![image](https://i.imgur.com/topjx8v.png)

[Megaport](https://www.megaport.com/) operates a global, Software Defined Network which enables their customers to 
manage their connectivity in close to real time. The Megaport API allows customers to interact with their account in 
the same way as they might using the [Web Portal](https://portal.megaport.com/login).

Use the power of megaLib to order your very own virtual router in the cloud with connectivity AWS in just a few lines:
![image](https://i.imgur.com/WlZOkup.png)

## Who Uses megaLib
Anyone who has an existing Megaport account and would like to automate Megaport things in Python. If you don't have an 
account you can [signup here](https://portal.megaport.com/signup).

## How it Works
megaLib functions as a Python wrapper for the [public Megaport API](https://api.megaport.com/) by providing a library of 
functions to simplify your next mega-project.

If you would like more information on the Megaport API I suggest checking out the 
[Megaport API documentation](https://dev.megaport.com/) and the 
[Megaport Knowledgebase Articles](https://knowledgebase.megaport.com/open-api/) on the API.

## Installation
Requests is required, Requests can be installed using pipenv or pip:

![image](https://i.imgur.com/2BmdBKY.png)

See the [Requests documentation](http://docs.python-requests.org/en/master/user/install/) for alternative installation 
methods.

Install megaLib using pip:

![image](https://i.imgur.com/D4xnjpe.png)

Alternatively, install megaLib by cloning [this git repository](https://github.com/jvdspeare/megaLib) to a local 
directory, verifying the requirements are met and executing setup.py:

![image](https://i.imgur.com/wZV9ZsK.png)

## Usage

You can find example code snippets for the functions [here](https://github.com/jvdspeare/megaLib/tree/master/examples). 
Examples of more functional code are [here](https://github.com/jvdspeare/megaLib/tree/master/demos). 
Additional resources can be found on the [Wiki](https://github.com/jvdspeare/megaLib/wiki).

## Built With
[Requests](https://github.com/requests/requests) - Python HTTP Requests for Humans.

## How to Contribute
1.  Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
2.  Fork [the repository](https://github.com/jvdspeare/megaLib) on GitHub to start making your changes to the master 
branch (or branch off of it).
3.  Write a test which shows that the bug was fixed or that the feature
    works as expected.
4.  Send a pull request and bug the maintainer until it gets merged and published.

## License
This project is licensed under the GNU General Public License v3.0 - see 
[LICENSE](https://github.com/jvdspeare/megaLib/blob/master/LICENSE) for more details.

## Disclaimer
This project including this git repository, is not affiliated, associated, authorized, endorsed by, or in any way 
officially connected with Megaport, or any of its subsidiaries or its affiliates.

Please refrain from contacting Megaport regarding any issues or support of this project. Instead feel free to submit an 
issue via this git repository.

==> megaLib-0.9.5.1.tar.gz: megaLib-0.9.5.1/README.md <==
# megaLib
[![image](https://img.shields.io/badge/License-GPLv3-lightgrey.svg)](https://github.com/jvdspeare/megaLib/blob/master/LICENSE)
[![image](https://img.shields.io/badge/Python-3.x-blue.svg)](https://www.python.org/)
[![image](https://img.shields.io/badge/API-Megaport-red.svg)](https://api.megaport.com/)
[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/jvdspeare)

megaLib is a Python wrapper for the [Megaport RESTful API](https://dev.megaport.com/).

![image](https://i.imgur.com/topjx8v.png)

[Megaport](https://www.megaport.com/) operates a global, Software Defined Network which enables their customers to 
manage their connectivity in close to real time. The Megaport API allows customers to interact with their account in 
the same way as they might using the [Web Portal](https://portal.megaport.com/login).

Use the power of megaLib to order your very own virtual router in the cloud with connectivity to AWS in just a few 
lines:
![image](https://i.imgur.com/WlZOkup.png)

## Who Uses megaLib
Anyone who has an existing Megaport account and would like to automate Megaport things in Python. If you don't have an 
account you can [signup here](https://portal.megaport.com/signup).

## How it Works
megaLib functions as a Python wrapper for the [public Megaport API](https://api.megaport.com/) by providing a library of 
functions to simplify your next mega-project.

If you would like more information on the Megaport API I suggest checking out the 
[Megaport API documentation](https://dev.megaport.com/) and the 
[Megaport Knowledgebase Articles](https://knowledgebase.megaport.com/open-api/) on the API.

## Installation
Requests is required, Requests can be installed using pipenv or pip:

![image](https://i.imgur.com/2BmdBKY.png)

See the [Requests documentation](http://docs.python-requests.org/en/master/user/install/) for alternative installation 
methods.

Install megaLib using pip:

![image](https://i.imgur.com/D4xnjpe.png)

Alternatively, install megaLib by cloning [this git repository](https://github.com/jvdspeare/megaLib) to a local 
directory, verifying the requirements are met and executing setup.py:

![image](https://i.imgur.com/wZV9ZsK.png)

## Usage

You can find example code snippets for the functions [here](https://github.com/jvdspeare/megaLib/tree/master/examples). 
Examples of more functional code are [here](https://github.com/jvdspeare/megaLib/tree/master/demos). 
Additional resources can be found on the [Wiki](https://github.com/jvdspeare/megaLib/wiki).

## Built With
[Requests](https://github.com/requests/requests) - Python HTTP Requests for Humans.

## How to Contribute
1.  Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
2.  Fork [the repository](https://github.com/jvdspeare/megaLib) on GitHub to start making your changes to the master 
branch (or branch off of it).
3.  Write a test which shows that the bug was fixed or that the feature
    works as expected.
4.  Send a pull request and bug the maintainer until it gets merged and published.

## License
This project is licensed under the GNU General Public License v3.0 - see 
[LICENSE](https://github.com/jvdspeare/megaLib/blob/master/LICENSE) for more details.

## Disclaimer
This project including this git repository, is not affiliated, associated, authorized, endorsed by, or in any way 
officially connected with Megaport, or any of its subsidiaries or its affiliates.

Please refrain from contacting Megaport regarding any issues or support of this project. Instead feel free to submit an 
issue via this git repository.
